@@ -10,12 +10,12 @@ import pandas as pd
 from dateutil import tz
 from click import echo
 
-async def RUN(configFile=None,override=False):
+async def RUN(configFile=None):
     start_time = time.perf_counter()
     echo(f'Start time: {start_time:0.5f}')
     mnets = {}
     masternet = {}
-    cfg = model.APPCONFIG(configFile,override)
+    cfg = model.APPCONFIG(configFile)
     mpi = lib.MerakiApi(cfg)
     db = mpi.getAPI()
     echo("LOADING CONFIG FROM ENV")
